Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1221)

Unified Diff: samples/todomvc/ios/TodoMVC/AppDelegate.mm

Issue 1659163007: Rename fletch -> dartino (Closed) Base URL: https://github.com/dartino/sdk.git@master
Patch Set: address comments Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « samples/todomvc/ios/TodoMVC.xcodeproj/project.pbxproj ('k') | samples/todomvc/todomvc_shared.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: samples/todomvc/ios/TodoMVC/AppDelegate.mm
diff --git a/samples/todomvc/ios/TodoMVC/AppDelegate.mm b/samples/todomvc/ios/TodoMVC/AppDelegate.mm
index cd95b7a834e75afb0d58d89eb45ec20e0a8a6e9c..fce9126af700cca8726470422b0c215ed316bd4b 100644
--- a/samples/todomvc/ios/TodoMVC/AppDelegate.mm
+++ b/samples/todomvc/ios/TodoMVC/AppDelegate.mm
@@ -4,7 +4,7 @@
#import "AppDelegate.h"
-#include "include/fletch_api.h"
+#include "include/dartino_api.h"
#include "include/service_api.h"
#include "todomvc_presenter.h"
@@ -23,25 +23,25 @@ static dispatch_queue_t queue;
NSBundle* mainBundle = [NSBundle mainBundle];
NSString* snapshot =
[mainBundle pathForResource: @"todomvc" ofType: @"snapshot"];
// Read the snapshot and pass it to fletch.
NSData* data = [[NSData alloc] initWithContentsOfFile:snapshot];
unsigned char* bytes =
reinterpret_cast<unsigned char*>(const_cast<void*>(data.bytes));
- NSLog(@"Fletch execution started\n");
- FletchProgram program = FletchLoadSnapshot(bytes, data.length);
- FletchRunMain(program);
- FletchDeleteProgram(program);
- NSLog(@"Fletch execution terminated\n");
+ NSLog(@"Dartino execution started\n");
+ DartinoProgram program = DartinoLoadSnapshot(bytes, data.length);
+ DartinoRunMain(program);
+ DartinoDeleteProgram(program);
+ NSLog(@"Dartino execution terminated\n");
}
- (BOOL)application:(UIApplication *)application
didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
- // Setup Fletch and the Fletch service API.
- FletchSetup();
+ // Setup Dartino and the Dartino service API.
+ DartinoSetup();
ServiceApiSetup();
- // Create dispatch queue to run the Fletch VM on a separate thread.
- queue = dispatch_queue_create("com.google.fletch.dartQueue",
+ // Create dispatch queue to run the Dartino VM on a separate thread.
+ queue = dispatch_queue_create("com.google.dartino.dartQueue",
DISPATCH_QUEUE_SERIAL);
// Post task to load and run snapshot on a different thread.
dispatch_async(queue, ^() {
@@ -85,10 +85,10 @@ static dispatch_queue_t queue;
// Called when the application is about to terminate. Save data if
// appropriate. See also applicationDidEnterBackground:.
// Tear down the service API structures and Fletch.
TodoMVCService::tearDown();
ServiceApiTearDown();
- FletchTearDown();
+ DartinoTearDown();
}
@end
« no previous file with comments | « samples/todomvc/ios/TodoMVC.xcodeproj/project.pbxproj ('k') | samples/todomvc/todomvc_shared.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -23,25 +23,25 @@ static dispatch_queue_t queue;
NSString* snapshot =
[mainBundle pathForResource: @"todomvc" ofType: @"snapshot"];
- // Read the snapshot and pass it to fletch.
+ // Read the snapshot and pass it to dartino.
NSData* data = [[NSData alloc] initWithContentsOfFile:snapshot];
unsigned char* bytes =
@@ -85,10 +85,10 @@ static dispatch_queue_t queue;
// Called when the application is about to terminate. Save data if
// appropriate. See also applicationDidEnterBackground:.
- // Tear down the service API structures and Fletch.
+ // Tear down the service API structures and Dartino.
TodoMVCService::tearDown();
ServiceApiTearDown();
This is Rietveld 408576698